@@ -11,7 +11,7 @@
 #include "KBlocksField.h"
 #include "KBlocksPiece.h"
 
-#include <stdlib.h>
+#include <QtGlobal>
 
 KBlocksSingleGame::KBlocksSingleGame(int gameIndex, int fieldWidth, int fieldHeight, int showPieceCount, int messagePoolSize)
 {
@@ -125,11 +125,11 @@ int KBlocksSingleGame::punishGame(int lineCount, int punishSeed)
         mpGameRecorder->append(mGameIndex, RecordDataType_PunishLineSeed, punishSeed);
     }
 
-    srand(punishSeed);
+    qsrand(punishSeed);
     int punishIndex = 0;
     for (int i = 0; i < lineCount; i++) {
         setCurrentPiece(0, -1, 0);
-        punishIndex = rand() % width;
+        punishIndex = qrand() % width;
         mpField->addPunishLine(lineCount, punishIndex);
     }
 
